@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# (c) YashDK [yash-dk@github]
+
 
 from ..consts.DefaultCommands import Commands
 from ..core.getVars import get_val 
@@ -13,13 +13,13 @@ def get_command(command):
     #Get the command from the constants supplied
     try:
         cmd = getattr(Commands,command)
-        torlog.debug(f"Getting the command {command} from file:- {cmd}")
+        torlog.debug(f"getting the command {command} from file: {cmd}")
     except AttributeError:pass
 
     #Get the commands form the env [overlap]
     #try:
     envcmd = os.environ.get(command)
-    torlog.debug(f"Getting the command {command} from file:- {envcmd}")
+    torlog.debug(f"hetting the command {command} from file: {envcmd}")
     cmd =  envcmd if envcmd is not None else cmd
 
     #Get the commands form the DB [overlap]
@@ -27,10 +27,10 @@ def get_command(command):
 
     if cmd is None:
         torlog.debug(f"None Command Error occured for command {command}")
-        raise Exception("The command was not found in either the constants, environment or database. Command is :- {}".format(command))
+        raise Exception("the command was not found in either the constants, environment or database. command is: {}".format(command))
     
     cmd = cmd.strip("/")
     cmd += get_val("BOT_CMD_POSTFIX")
 
-    torlog.debug(f"Final resolver for {command} is {cmd}")
+    torlog.debug(f"final resolver for {command} is {cmd}")
     return f"/{cmd}"
\ No newline at end of file
