@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-# (c) YashDK [yash-dk@github]
 
 import os,subprocess,logging,re,time,json,traceback
 from telethon.tl.types import KeyboardButtonUrl
@@ -20,7 +19,7 @@ async def rclone_driver(path,message, user_msg, dl_task):
     # get the default drive
     conf_path = await get_config()
     if conf_path is None:
-        torlog.info("The confi file not found")
+        torlog.info("the configuration file was not found.")
         return None
     else:
         drive_name = get_val("DEF_RCLONE_DRIVE")
@@ -33,23 +32,23 @@ async def rclone_driver(path,message, user_msg, dl_task):
             return await rclone_upload(path,message,user_msg,drive_name,rem_base,edtime,conf_path, ul_task)
         except:
             await ul_task.set_inactive()
-            torlog.exception("Stuff gone wrong in here")
+            torlog.exception("something went wrong. check logs for more infomation.")
             return 
 
 # add user prompt here
 async def rclone_upload(path,message,user_msg,dest_drive,dest_base,edit_time,conf_path, task):
     # this function will need a driver for him :o
     if not os.path.exists(path):
-        torlog.info(f"Returning none cuz the path {path} not found")
-        await task.set_inactive(f"Returning none cuz the path {path} not found")
+        torlog.info(f"returning none cause the path {path} not found.")
+        await task.set_inactive(f"returning none cause the path {path} not found")
         return None
     omsg = user_msg
     await task.set_original_message(omsg)
     upload_db.register_upload(omsg.chat_id, omsg.id)
     data = "upcancel {} {} {}".format(omsg.chat_id,omsg.id,omsg.sender_id)
-    buts = [KeyboardButtonCallback("Cancel upload.",data.encode("UTF-8"))]
+    buts = [KeyboardButtonCallback("cancel upload.",data.encode("UTF-8"))]
     
-    msg = await message.reply("<b>Uploading to configured drive.... will be updated soon.",parse_mode="html", buttons=buts)
+    msg = await message.reply("<b>uploading to configured drive.... will be updated soon.",parse_mode="html", buttons=buts)
     await task.set_message(msg)
 
     if os.path.isdir(path):
@@ -69,15 +68,15 @@ async def rclone_upload(path,message,user_msg,dest_drive,dest_base,edit_time,con
         rcres = await rclone_process_display(rclone_pr,edit_time,msg, message, omsg, task)
         
         if rcres is False:
-            await message.edit(message.text + "\nCanceled Rclone Upload")
+            await message.edit(message.text + "\ncanceled rclone upload.")
             await msg.delete()
             rclone_pr.kill()
             task.cancel = True
-            await task.set_inactive("Canceled Rclone Upload")
+            await task.set_inactive("canceled rclone upload.")
             return task
             
 
-        torlog.info("Upload complete")
+        torlog.info("upload complete")
         gid = await get_glink(dest_drive,dest_base,os.path.basename(path),conf_path)
         torlog.info(f"Upload folder id :- {gid}")
         
@@ -85,7 +84,7 @@ async def rclone_upload(path,message,user_msg,dest_drive,dest_base,edit_time,con
 
         buttons = []
         buttons.append(
-            [KeyboardButtonUrl("Drive URL",folder_link)]
+            [KeyboardButtonUrl("drive url",folder_link)]
         )
         gd_index = get_val("GD_INDEX_URL")
         if gd_index:
@@ -93,11 +92,11 @@ async def rclone_upload(path,message,user_msg,dest_drive,dest_base,edit_time,con
             index_link = requote_uri(index_link)
             torlog.info("index link "+str(index_link))
             buttons.append(
-                [KeyboardButtonUrl("Index URL",index_link)]
+                [KeyboardButtonUrl("index url",index_link)]
             )
 
 
-        txtmsg = "<a href='tg://user?id={}'>Done</a>\n#uploads\nUPLOADED FOLDER :-<code>{}</code>\nTo Drive.".format(omsg.sender_id,os.path.basename(path))
+        txtmsg = "<a href='tg://user?id={}'>finished leech.</a>\nuploaded folder:<code>{}</code>\nto drive.".format(omsg.sender_id,os.path.basename(path))
         
         await omsg.reply(txtmsg,buttons=buttons,parse_mode="html")
         await msg.delete()
@@ -119,14 +118,14 @@ async def rclone_upload(path,message,user_msg,dest_drive,dest_base,edit_time,con
         rcres = await rclone_process_display(rclone_pr,edit_time,msg, message, omsg, task)
         
         if rcres is False:
-            await message.edit(message.text + "\nCanceled Rclone Upload")
+            await message.edit(message.text + "\ncanceled rclone upload")
             await msg.delete()
             rclone_pr.kill()
             task.cancel = True
-            await task.set_inactive("Canceled Rclone Upload")
+            await task.set_inactive("canceled rclone upload")
             return task
 
-        torlog.info("Upload complete")
+        torlog.info("upload complete")
         gid = await get_glink(dest_drive,dest_base,os.path.basename(path),conf_path,False)
         torlog.info(f"Upload folder id :- {gid}")
 
@@ -134,7 +133,7 @@ async def rclone_upload(path,message,user_msg,dest_drive,dest_base,edit_time,con
 
         file_link = f"https://drive.google.com/file/d/{gid[0]}/view"
         buttons.append(
-            [KeyboardButtonUrl("Drive URL",file_link)]
+            [KeyboardButtonUrl("drive url",file_link)]
         )
         gd_index = get_val("GD_INDEX_URL")
         if gd_index:
@@ -142,10 +141,10 @@ async def rclone_upload(path,message,user_msg,dest_drive,dest_base,edit_time,con
             index_link = requote_uri(index_link)
             torlog.info("index link "+str(index_link))
             buttons.append(
-                [KeyboardButtonUrl("Index URL",index_link)]
+                [KeyboardButtonUrl("index url",index_link)]
             )
 
-        txtmsg = "<a href='tg://user?id={}'>Done</a>\n#uploads\nUPLOADED FILE :-<code>{}</code>\nTo Drive.".format(omsg.sender_id,os.path.basename(path))
+        txtmsg = "<a href='tg://user?id={}'>finished leech.</a>\nuploaded file:<code>{}</code>\nto drive.".format(omsg.sender_id,os.path.basename(path))
 
         
         await omsg.reply(txtmsg,buttons=buttons,parse_mode="html")
@@ -163,7 +162,7 @@ async def rclone_process_display(process,edit_time,msg, omessage, cancelmsg, tas
         
         data = process.stdout.readline().decode()
         data = data.strip()
-        mat = re.findall("Transferred:.*ETA.*",data)
+        mat = re.findall("transferred:.*eta.*",data)
         
         if mat is not None:
             if len(mat) > 0:
@@ -230,7 +229,7 @@ async def get_glink(drive_name,drive_base,ent_name,conf_path,isdir=True):
         name = data[0]["Name"]
         return (id, name)
     except Exception:
-        torlog.error("Error Occured while getting id ::- {} {}".format(traceback.format_exc(), stdout))
+        torlog.error("error occured while getting id: {} {}".format(traceback.format_exc(), stdout))
 
 async def get_config():
     # this car requires to access the blob
